@@ -3,6 +3,8 @@
 #[cfg(feature = "serde")]
 use serde::de::{Deserialize, Deserializer, Visitor};
 use std::borrow::Cow;
+use std::ffi::OsStr;
+use std::process::Command;
 use std::str::CharIndices;
 
 /// A command parsed into arguments that might be borrowed from the source.
@@ -27,6 +29,7 @@ pub struct ArgIter<'a> {
 
 impl<'a> ArgIter<'a> {
     /// Construct a new argument iterator from the source.
+    #[inline]
     pub fn new(source: &'a str) -> Self {
         ArgIter {
             source,
@@ -38,6 +41,7 @@ impl<'a> ArgIter<'a> {
 impl<'a> Iterator for ArgIter<'a> {
     type Item = Cow<'a, str>;
 
+    #[inline]
     fn next(&mut self) -> Option<Self::Item> {
         #[derive(Clone, Copy)]
         enum State {
@@ -128,8 +132,38 @@ impl<'a> Iterator for ArgIter<'a> {
     }
 }
 
+impl<S: AsRef<OsStr>> Cmd<S> {
+    /// Turn `Cmd` into an actual command that can be executed.
+    #[inline]
+    pub fn make_command(&self) -> Command {
+        let mut command = Command::new(&self.path);
+        command.args(&self.args);
+        command
+    }
+}
+
+impl<'a> From<ArgIter<'a>> for Cmd<Cow<'a, str>> {
+    #[inline]
+    fn from(mut iter: ArgIter<'a>) -> Self {
+        let path = iter.next().unwrap_or(Cow::Borrowed(""));
+        let args = iter.collect();
+        Cmd { path, args }
+    }
+}
+
+impl From<ArgIter<'_>> for Cmd {
+    #[inline]
+    fn from(iter: ArgIter) -> Self {
+        let mut iter = iter.map(|s| s.to_string());
+        let path = iter.next().unwrap_or_else(|| "".to_string());
+        let args = iter.collect();
+        Cmd { path, args }
+    }
+}
+
 #[cfg(feature = "serde")]
 impl<'de: 'a, 'a> Deserialize<'de> for Cmd<Cow<'a, str>> {
+    #[inline]
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: Deserializer<'de>,
@@ -143,13 +177,12 @@ impl<'de: 'a, 'a> Deserialize<'de> for Cmd<Cow<'a, str>> {
                 write!(formatter, "a command string")
             }
 
+            #[inline]
             fn visit_borrowed_str<E>(self, v: &'de str) -> Result<Self::Value, E> {
-                let mut iter = ArgIter::new(v);
-                let path = iter.next().unwrap_or(Cow::Borrowed(""));
-                let args = iter.collect();
-                Ok(Cmd { path, args })
+                Ok(ArgIter::new(v).into())
             }
 
+            #[inline]
             fn visit_str<E>(self, v: &str) -> Result<Self::Value, E> {
                 let mut iter = ArgIter::new(v).map(|s| Cow::Owned(s.to_string()));
                 let path = iter.next().unwrap_or_else(|| "".into());
@@ -164,6 +197,7 @@ impl<'de: 'a, 'a> Deserialize<'de> for Cmd<Cow<'a, str>> {
 
 #[cfg(feature = "serde")]
 impl<'de> Deserialize<'de> for Cmd {
+    #[inline]
     fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
     where
         D: Deserializer<'de>,
@@ -177,11 +211,9 @@ impl<'de> Deserialize<'de> for Cmd {
                 write!(formatter, "a command string")
             }
 
+            #[inline]
             fn visit_str<E>(self, v: &str) -> Result<Self::Value, E> {
-                let mut iter = ArgIter::new(v).map(|s| s.to_string());
-                let path = iter.next().unwrap_or_else(|| "".into());
-                let args = iter.collect();
-                Ok(Cmd { path, args })
+                Ok(ArgIter::new(v).into())
             }
         }
 
